"{ Package: 'jn:refactoring_custom' }"

TestCase subclass:#CustomNewSystemBrowserTests
	instanceVariableNames:'browser mock menu'
	classVariableNames:''
	poolDictionaries:''
	category:'Interface-Refactoring-Custom-UI-Tests'
!

!CustomNewSystemBrowserTests methodsFor:'initialization & release'!

setUp
    super setUp.

    mock := CustomMock new.
    menu := Menu labels: 'label' values: nil.
    browser := (mock mockOf: Tools::NewSystemBrowser)
        compileMockMethod: 'information: aString
            self objectAttributeAt: #testInformation put: aString';
        compileMockMethod: 'information
            ^ self objectAttributeAt: #testInformation';
        compileMockMethod: 'theSingleSelectedClass: aClass
            self objectAttributeAt: #testTheSingleSelectedClass put: aClass';
        compileMockMethod: 'theSingleSelectedClass
            ^ self objectAttributeAt: #testTheSingleSelectedClass';
        compileMockMethod: 'createBuffer ^ true';
        compileMockMethod: 'switchToClass: aClass
            self objectAttributeAt: #testSwitchToClass put: aClass';
        compileMockMethod: 'switchToClass
            ^ self objectAttributeAt: #testSwitchToClass';
        compileMockMethod: 'selectProtocol: aProtocol
            self objectAttributeAt: #testSelectProtocol put: aProtocol';
        compileMockMethod: 'selectProtocol
            ^ self objectAttributeAt: #testSelectProtocol';
        yourself.

    "Modified: / 26-12-2014 / 18:42:47 / Jakub Nesveda <nesvejak@fit.cvut.cz>"
!

tearDown

    mock unmockAll.
    
    super tearDown.

    "Modified: / 26-12-2014 / 19:17:51 / Jakub Nesveda <nesvejak@fit.cvut.cz>"
! !

!CustomNewSystemBrowserTests methodsFor:'tests'!

test_class_menu_extension_navigate_to_test_case_custom_extensions
    | expectedClass actualClass |

    expectedClass := CustomRBMethodTests.
    browser theSingleSelectedClass: RBMethod.
    browser classMenuExtensionNavigateToTestCase: menu.
    menu lastItem itemValue value. "Call menu item action block"
    actualClass := browser switchToClass.

    self assert: expectedClass = actualClass.
    self assert: (browser selectProtocol) == #tests

    "Created: / 26-12-2014 / 18:58:56 / Jakub Nesveda <nesvejak@fit.cvut.cz>"
!

test_class_menu_extension_navigate_to_test_case_found
    | expectedClass actualClass |

    expectedClass := CustomContextTests.
    browser theSingleSelectedClass: CustomContext.
    browser classMenuExtensionNavigateToTestCase: menu.
    menu lastItem itemValue value. "Call menu item action block"
    actualClass := browser switchToClass.

    self assert: expectedClass = actualClass.
    self assert: (browser selectProtocol) == #tests

    "Created: / 26-12-2014 / 18:53:34 / Jakub Nesveda <nesvejak@fit.cvut.cz>"
!

test_class_menu_extension_navigate_to_test_case_not_found
    | expectedInformation actualInformation |

    expectedInformation := 'Test Case named CustomNewSystemBrowserTestsTests not found'.
    browser theSingleSelectedClass: CustomNewSystemBrowserTests.
    browser classMenuExtensionNavigateToTestCase: menu.
    menu lastItem itemValue value. "Call menu item action block"
    actualInformation := browser information.

    self assert: expectedInformation = actualInformation

    "Created: / 26-12-2014 / 18:32:23 / Jakub Nesveda <nesvejak@fit.cvut.cz>"
!

test_class_menu_extension_navigate_to_test_case_placed_after_generate
    | expectedPosition actualPosition foundItem |

    expectedPosition := 3.

    menu := Menu labels: 'Label_01
Generate
Label_02' values: nil.

    browser classMenuExtensionNavigateToTestCase: menu.
    actualPosition := 0.
    foundItem := false.
    menu itemsDo: [ :item |  
        foundItem ifFalse: [
            actualPosition := actualPosition + 1.
            foundItem := (item label = 'Open Test Case Class').
        ]
    ].

    self assert: expectedPosition = actualPosition

    "Created: / 26-12-2014 / 19:01:59 / Jakub Nesveda <nesvejak@fit.cvut.cz>"
! !

